==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/ui/common/tooltips/version-control-tip/version-control-tip.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Component, Input } from '@angular/core';
import { VersionControlInformation, VersionControlTipInput } from '../../../../state/flow';

@Component({
    selector: 'version-control-tip',
    templateUrl: './version-control-tip.component.html',
    styleUrls: ['./version-control-tip.component.scss']
})
export class VersionControlTip {
    @Input() left = 0;
    @Input() top = 0;
    @Input() data: VersionControlTipInput | undefined;

    getTrackingMessage(): string {
        if (this.data) {
            const vci: VersionControlInformation = this.data.versionControlInformation;
            return `Tracking to "${vci.flowName}" Version ${vci.version} in "${vci.registryName} - ${vci.bucketName}"`;
        }

        return '';
    }
}

==> nifi-2.8.0-source-release.zip: nifi-2.8.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/ui/common/tooltips/version-control-tip/version-control-tip.component.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Component, Input } from '@angular/core';
import { VersionControlInformation, VersionControlTipInput } from '../../../../state/flow';
import { RegistryClientEntity } from '../../../../../../state/shared';

@Component({
    selector: 'version-control-tip',
    templateUrl: './version-control-tip.component.html',
    styleUrls: ['./version-control-tip.component.scss']
})
export class VersionControlTip {
    @Input() left = 0;
    @Input() top = 0;
    @Input() data: VersionControlTipInput | undefined;

    getTrackingMessage(): string {
        if (this.data) {
            const vci: VersionControlInformation = this.data.versionControlInformation;
            return `Tracking to "${vci.flowName}" Version ${vci.version} in "${vci.registryName} - ${vci.bucketName}"`;
        }

        return '';
    }

    supportsBranching(): boolean {
        if (this.data?.registryClients && this.data?.registryClients.length > 0) {
            const vci = this.data.versionControlInformation;
            return this.data.registryClients.some((client: RegistryClientEntity) => {
                return client.id === vci.registryId && client.component.supportsBranching;
            });
        }
        return false;
    }
}
